@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
 import webbrowser
 
@@ -140,10 +140,6 @@ class ModelerParametersDialog(QDialog):
         line.setFrameShape(QFrame.HLine)
         line.setFrameShadow(QFrame.Sunken)
         self.verticalLayout.addWidget(line)
-        self.algorithmItem = QgsGui.instance().processingGuiRegistry().algorithmConfigurationWidget(self._alg)
-        if self.configuration:
-            self.algorithmItem.setConfiguration(self.configuration)
-        self.verticalLayout.addWidget(self.algorithmItem)
 
         widget_context = QgsProcessingParameterWidgetContext()
         if iface is not None:
@@ -151,6 +147,14 @@ class ModelerParametersDialog(QDialog):
         widget_context.setModel(self.model)
         widget_context.setModelChildAlgorithmId(self.childId)
 
+        self.algorithmItem = QgsGui.instance().processingGuiRegistry().algorithmConfigurationWidget(self._alg)
+        if self.algorithmItem:
+            self.algorithmItem.setWidgetContext(widget_context)
+            self.algorithmItem.registerProcessingContextGenerator(self.context_generator)
+        if self.configuration:
+            self.algorithmItem.setConfiguration(self.configuration)
+        self.verticalLayout.addWidget(self.algorithmItem)
+
         for param in self._alg.parameterDefinitions():
             if param.flags() & QgsProcessingParameterDefinition.FlagAdvanced:
                 self.advancedButton = QPushButton()
@@ -169,9 +173,9 @@ class ModelerParametersDialog(QDialog):
             wrapper = WidgetWrapperFactory.create_wrapper(param, self)
             self.wrappers[param.name()] = wrapper
 
+            wrapper.setWidgetContext(widget_context)
+            wrapper.registerProcessingContextGenerator(self.context_generator)
             if issubclass(wrapper.__class__, QgsProcessingModelerParameterWidget):
-                wrapper.setWidgetContext(widget_context)
-                wrapper.registerProcessingContextGenerator(self.context_generator)
                 widget = wrapper
             else:
                 widget = wrapper.widget
